@@ -1,7 +1,8 @@
 __author__ = 'maroun'
-
+__version__ = '0.0.6'
 
 import os
+import re
 
 from nose.plugins import Plugin
 
@@ -12,8 +13,8 @@ class DocstringModifier(Plugin):
     docstring.
 
     Usage examples:
-      > python main.py --with-docstring-modifier --prefix=id --suffix=type
-      > python main.py --with-docstring-modifier --replace=a,A --suffix=id
+      > nosetest --with-docstring-modifier --prefix=id,section --suffix=type
+      > nosetest --with-docstring-modifier --replace=('a','A') --first-line
     """
 
     name = 'docstring-modifier'
@@ -25,13 +26,19 @@ class DocstringModifier(Plugin):
         if not test:
             return
 
+        # get prefixes and suffixes
         prefix_list = self.conf.options.prefix
         suffix_list = self.conf.options.suffix
-
         prefix = self._get_affix(prefix_list, test)
         suffix = self._get_affix(suffix_list, test)
 
-        docstring = self._get_docstring(test)
+        # modify docstring if necessary
+        docstring = test.__doc__
+        if not docstring:
+            docstring = str(running_test).split('.')[-1]
+        else:
+            docstring = self._get_first_line(docstring)
+            docstring = self._get_replaced_docstring(docstring)
 
         return '{} {} {}'.format(prefix, docstring, suffix).strip()
 
@@ -48,8 +55,11 @@ class DocstringModifier(Plugin):
                  'after the original docstring, comma separated')
         parser.add_option(
             '--replace',
-            help='Replace characters in original docstring, for example:'
-                 '--replace=a,A'
+            help="Replace characters in original docstring, for example:"
+                 "--replace=('a','A')")
+        parser.add_option(
+            '--first-line', action="store_true",
+            help='Prints only the first line of the docstring'
         )
 
     @staticmethod
@@ -67,19 +77,38 @@ class DocstringModifier(Plugin):
 
         func_dict = func_dict.split(',')
 
-        affix = [str(running_test.func_dict.get(key, '')) for key in func_dict]
-        return '(' + ', '.join(filter(len, affix)) + ')'
+        affix = [running_test.func_dict.get(key, None) for key in func_dict]
+        affix = filter(None, affix)
 
-    def _get_docstring(self, running_test):
+        if not affix:
+            return ''
+
+        return '(' + ', '.join(filter(len, map(str, affix))) + ')'
+
+    def _get_replaced_docstring(self, docstring):
         """
-        Returns modified docstring if --replace is toggled, original otherwise.
+        Returns modified docstring if --replace is enabled, original otherwise.
 
         :return: modified docstring
         """
-        docstring = running_test.__doc__
-        replace_args = (self.conf.options.replace or '').split(',')
+        if not self.conf.options.replace:
+            return docstring
 
-        if len(replace_args) == 2:
-            return docstring.replace(replace_args[0], replace_args[1])
+        pattern = re.compile("^\('(.+)','(.+)\'\)$")
+        match = pattern.match(self.conf.options.replace)
+        if not match:
+            return docstring
 
-        return docstring
\ No newline at end of file
+        return docstring.replace(match.group(1), match.group(2))
+
+    def _get_first_line(self, docstring):
+        """
+        Returns first line of the docstring if --first-line is enabled, original
+        otherwise.
+
+        :return: first line of docstring
+        """
+        if self.conf.options.first_line:
+            return docstring.split('\n', 1)[0]
+
+        return ' '.join(docstring.split())
\ No newline at end of file
